@@ -26,17 +26,17 @@
 ##  shiela.pl: control program (syntax: Perl)
 ##
 
-my $version = '1.0.0';
+my $version = '1.0.1';
 
 require 5.005;
 
-use strict;       # shipped with Perl since 5.000
-use POSIX;        # shipped with Perl since 5.000
-use IO::File;     # shipped with Perl since 5.003
-use IO::Handle;   # shipped with Perl since 5.003
-use IPC::Open2;   # shipped with Perl since 5.003
-use Data::Dumper; # shipped with Perl since 5.005
-use Cwd;          # shipped with Perl since 5.005
+use strict;           # shipped with Perl since 5.000
+use POSIX;            # shipped with Perl since 5.000
+use IO::File;         # shipped with Perl since 5.003
+use IO::Handle;       # shipped with Perl since 5.003
+use IPC::Open2;       # shipped with Perl since 5.003
+use Data::Dumper;     # shipped with Perl since 5.005
+use Cwd qw(abs_path); # shipped with Perl since 5.005
 
 #   DEBUGGING
 $Data::Dumper::Purity = 1;
